==> tuia-treasure-center-api-1.8.0.3-RELEASE-sources.jar: cn/tuia/tuia/treasure/center/api/dto/SlotPositionDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;

import cn.tuia.tuia.treasure.center.api.enums.SlotPositionConfig;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xuefeng on 2018/12/19.
 */
public class SlotPositionDto implements Serializable {

    private static final long serialVersionUID = 1L;

    private Long id;

    private Integer positionCode;

    private String positionDesc;

    private Boolean stable;

    private Boolean opened;

    private Boolean wxbOpened;

    private Boolean wyylOpened;

    private Boolean wlttOpened;

    private Boolean wybdOpened;

    private Date gmtCreate;

    private Date gmtModified;

    /**
     * 起始位置
     */
    private Integer firstAd;

    /**
     * 偏移量
     */
    private Integer offsetAd;

    /**
     * 广告位置配置
     */
    private SlotPositionConfig slotPositionConfig;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(Integer positionCode) {
        this.positionCode = positionCode;
    }

    public String getPositionDesc() {
        return positionDesc;
    }

    public void setPositionDesc(String positionDesc) {
        this.positionDesc = positionDesc;
    }

    public Boolean getStable() {
        return stable;
    }

    public void setStable(Boolean stable) {
        this.stable = stable;
    }

    public Boolean getOpened() {
        return opened;
    }

    public void setOpened(Boolean opened) {
        this.opened = opened;
    }

    public Boolean getWxbOpened() {
        return wxbOpened;
    }

    public void setWxbOpened(Boolean wxbOpened) {
        this.wxbOpened = wxbOpened;
    }

    public Boolean getWyylOpened() {
        return wyylOpened;
    }

    public void setWyylOpened(Boolean wyylOpened) {
        this.wyylOpened = wyylOpened;
    }

    public Boolean getWlttOpened() {
        return wlttOpened;
    }

    public void setWlttOpened(Boolean wlttOpened) {
        this.wlttOpened = wlttOpened;
    }

    public Boolean getWybdOpened() {
        return wybdOpened;
    }

    public void setWybdOpened(Boolean wybdOpened) {
        this.wybdOpened = wybdOpened;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public SlotPositionConfig getSlotPositionConfig() {
        return slotPositionConfig;
    }

    public void setSlotPositionConfig(SlotPositionConfig slotPositionConfig) {
        this.slotPositionConfig = slotPositionConfig;
    }

    public Integer getFirstAd() {
        return firstAd;
    }

    public void setFirstAd(Integer firstAd) {
        this.firstAd = firstAd;
    }

    public Integer getOffsetAd() {
        return offsetAd;
    }

    public void setOffsetAd(Integer offsetAd) {
        this.offsetAd = offsetAd;
    }
}

==> tuia-treasure-center-api-2.9.0.0-RELEASE-sources.jar: cn/tuia/tuia/treasure/center/api/dto/SlotPositionDto.java <==
package cn.tuia.tuia.treasure.center.api.dto;

import cn.tuia.tuia.treasure.center.api.enums.SlotPositionConfig;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by xuefeng on 2018/12/19.
 */
public class SlotPositionDto implements Serializable {

    private static final long serialVersionUID = 1L;

    private Long id;

    private Integer positionCode;

    private String positionDesc;

    private Boolean stable;

    private Boolean opened;

    private Boolean wxbOpened;

    private Boolean wyylOpened;

    private Boolean wlttOpened;

    private Boolean wybdOpened;

    private Boolean hjjwOpened;

    private Boolean peopleOpened;

    private Date gmtCreate;

    private Date gmtModified;


    public Boolean getPeopleOpened() {
        return peopleOpened;
    }

    public void setPeopleOpened(Boolean peopleOpened) {
        this.peopleOpened = peopleOpened;
    }

    /**
     * 起始位置
     */
    private Integer firstAd;

    /**
     * 偏移量
     */
    private Integer offsetAd;

    /**
     * 广告位置配置
     */
    private SlotPositionConfig slotPositionConfig;


    public Boolean getHjjwOpened() {
        return hjjwOpened;
    }

    public void setHjjwOpened(Boolean hjjwOpened) {
        this.hjjwOpened = hjjwOpened;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(Integer positionCode) {
        this.positionCode = positionCode;
    }

    public String getPositionDesc() {
        return positionDesc;
    }

    public void setPositionDesc(String positionDesc) {
        this.positionDesc = positionDesc;
    }

    public Boolean getStable() {
        return stable;
    }

    public void setStable(Boolean stable) {
        this.stable = stable;
    }

    public Boolean getOpened() {
        return opened;
    }

    public void setOpened(Boolean opened) {
        this.opened = opened;
    }

    public Boolean getWxbOpened() {
        return wxbOpened;
    }

    public void setWxbOpened(Boolean wxbOpened) {
        this.wxbOpened = wxbOpened;
    }

    public Boolean getWyylOpened() {
        return wyylOpened;
    }

    public void setWyylOpened(Boolean wyylOpened) {
        this.wyylOpened = wyylOpened;
    }

    public Boolean getWlttOpened() {
        return wlttOpened;
    }

    public void setWlttOpened(Boolean wlttOpened) {
        this.wlttOpened = wlttOpened;
    }

    public Boolean getWybdOpened() {
        return wybdOpened;
    }

    public void setWybdOpened(Boolean wybdOpened) {
        this.wybdOpened = wybdOpened;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public SlotPositionConfig getSlotPositionConfig() {
        return slotPositionConfig;
    }

    public void setSlotPositionConfig(SlotPositionConfig slotPositionConfig) {
        this.slotPositionConfig = slotPositionConfig;
    }

    public Integer getFirstAd() {
        return firstAd;
    }

    public void setFirstAd(Integer firstAd) {
        this.firstAd = firstAd;
    }

    public Integer getOffsetAd() {
        return offsetAd;
    }

    public void setOffsetAd(Integer offsetAd) {
        this.offsetAd = offsetAd;
    }
}
